#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import sqlalchemy


def upgrade(migrate_engine):
    meta = sqlalchemy.MetaData()
    meta.bind = migrate_engine

    stack = sqlalchemy.Table('stack', meta, autoload=True)
    stack.c.timeout.alter(nullable=True)


def downgrade(migrate_engine):
    meta = sqlalchemy.MetaData()
    meta.bind = migrate_engine

    stack = sqlalchemy.Table('stack', meta, autoload=True)
    # NOTE(viktors): We must be sure, that there are no nullable columns in
    #                `stack` table before we alter it.
    migrate_engine.execute('UPDATE stack set timeout=60 WHERE timeout IS NULL')
    stack.c.timeout.alter(nullable=False)
